###########
User Guide
###########

The user guide provides a quick start example in the :ref:`Tutorial Section <tutorial>` and the modules of the package are presented with all their
input and output options in the :ref:`Structure Section <structure_of_tsam>`.

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    tutorialDoc
    structureOfTsamDoc